summaryrefslogtreecommitdiffstats
path: root/certmanager/certificatewizardimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/certificatewizardimpl.cpp')
-rw-r--r--certmanager/certificatewizardimpl.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/certmanager/certificatewizardimpl.cpp b/certmanager/certificatewizardimpl.cpp
index 7127b3c2f..3c618e738 100644
--- a/certmanager/certificatewizardimpl.cpp
+++ b/certmanager/certificatewizardimpl.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -63,7 +63,7 @@
#include <kio/job.h>
#include <kio/netaccess.h>
-// Qt
+// TQt
#include <tqlineedit.h>
#include <tqtextedit.h>
#include <tqpushbutton.h>
@@ -83,7 +83,7 @@ static const unsigned int numKeyLengths = sizeof keyLengths / sizeof *keyLengths
static TQString attributeLabel( const TQString & attr, bool required ) {
if ( attr.isEmpty() )
- return TQString::null;
+ return TQString();
const TQString label = Kleo::DNAttributeMapper::instance()->name2label( attr );
if ( !label.isEmpty() )
if ( required )
@@ -108,14 +108,14 @@ static bool availForMod( const TQLineEdit * le ) {
}
/*
* Constructs a CertificateWizardImpl which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The wizard will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal wizard.
*/
-CertificateWizardImpl::CertificateWizardImpl( TQWidget* parent, const char* name, bool modal, WFlags fl )
- : CertificateWizard( parent, name, modal, fl )
+CertificateWizardImpl::CertificateWizardImpl( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : CertificateWizard( tqparent, name, modal, fl )
{
// don't allow to go to last page until a key has been generated
setNextEnabled( generatePage, false );
@@ -176,7 +176,7 @@ void CertificateWizardImpl::slotEnablePersonalDataPageExit() {
*/
CertificateWizardImpl::~CertificateWizardImpl()
{
// no need to delete child widgets, Qt does it all for us
}
static const char * oidForAttributeName( const TQString & attr ) {
@@ -429,8 +429,8 @@ void CertificateWizardImpl::sendCertificate( const TQString& email, const TQByte
TQString error;
TQCString dcopService;
int result = KDCOPServiceStarter::self()->
- tqfindServiceFor( "DCOP/Mailer", TQString::null,
- TQString::null, &error, &dcopService );
+ findServiceFor( "DCOP/Mailer", TQString(),
+ TQString(), &error, &dcopService );
if ( result != 0 ) {
kdDebug() << "Couldn't connect to KMail\n";
KMessageBox::error( this,
@@ -441,11 +441,11 @@ void CertificateWizardImpl::sendCertificate( const TQString& email, const TQByte
TQCString dummy;
// OK, so kmail (or kontact) is running. Now ensure the object we want is available.
// [that's not the case when kontact was already running, but kmail not loaded into it... in theory.]
- if ( !kapp->dcopClient()->tqfindObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) ) {
+ if ( !kapp->dcopClient()->findObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) ) {
DCOPRef ref( dcopService, dcopService ); // talk to the KUniqueApplication or its kontact wrapper
DCOPReply reply = ref.call( "load()" );
if ( reply.isValid() && (bool)reply ) {
- Q_ASSERT( kapp->dcopClient()->tqfindObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) );
+ Q_ASSERT( kapp->dcopClient()->findObject( dcopService, dcopObjectId, "", TQByteArray(), dummy, dummy ) );
} else
kdWarning() << "Error loading " << dcopService << endl;
}
@@ -108,14 +108,14 @@ static bool availForMod( const TQLineEdit * le ) {
}
/*
- * Constructs a CertificateWizardImpl which is a child of 'parent', with the
+ * Constructs a CertificateWizardImpl which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
@@ -176,7 +176,7 @@ void CertificateWizardImpl::slotEnablePersonalDataPageExit() {
CertificateWizardImpl::~CertificateWizardImpl()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
static const char * oidForAttributeName( const TQString & attr ) {